summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccount.h')
-rw-r--r--kopete/libkopete/kopeteaccount.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/libkopete/kopeteaccount.h b/kopete/libkopete/kopeteaccount.h
index 90ae678b..b7915b5e 100644
--- a/kopete/libkopete/kopeteaccount.h
+++ b/kopete/libkopete/kopeteaccount.h
@@ -301,7 +301,7 @@ public:
/**
* @brief Indicate whether the account is away.
*
- * This is a convenience method that queries @ref Contact::onlineStatus() on @ref myself().
+ * This is a convenience method that queries @ref Contact::onlinetqStatus() on @ref myself().
* This function is safe to call if @ref setMyself() has not been called yet.
*/
bool isAway() const;
@@ -409,7 +409,7 @@ protected slots:
*
* @param status the status to set all contacts of this account except @ref myself() to.
*/
- void setAllContactsStatus( const Kopete::OnlineStatus &status );
+ void setAllContactstqStatus( const Kopete::OnlineStatus &status );
signals:
/**
@@ -450,10 +450,10 @@ public slots:
/**
* @brief Go online for this service.
*
* @param initialStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/
- virtual void connect( const Kopete::OnlineStatus& initialStatus = OnlineStatus() ) = 0;
+ virtual void connect( const Kopete::OnlineStatus& initialtqStatus = OnlineStatus() ) = 0;
/**
* @brief Go offline for this service.
@@ -516,7 +516,7 @@ private slots:
/**
* The @ref myself() contact's online status changed.
*/
- void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newStatus, const Kopete::OnlineStatus &oldStatus );
+ void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newtqStatus, const Kopete::OnlineStatus &oldtqStatus );
/**
* The @ref myself() contact's property changed.
@@ -450,10 +450,10 @@ public slots:
* @brief Go online for this service.
*
- * @param initialStatus is the status to connect with. If it is an invalid status for this
+ * @param initialtqStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/